import fs from 'fs/promises'

import { Server } from 'socket.io'

import { BaseEvent } from '#application/base/baseEvent'
import Storage from '#application/storage'

export default class SpriteCreateEvent extends BaseEvent {
  constructor(
    private readonly io: Server,
    private readonly socket: TSocket
  ) {}

  public listen(): void {
    this.socket.on('gm:sprite:create', this.handleEvent.bind(this))
  }

  private async handleEvent(data: undefined, callback: (response: boolean) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      const public_folder = Storage.getPublicPath('sprites')

      // Ensure the folder exists
      await fs.mkdir(public_folder, { recursive: true })

      const sprite = await prisma.sprite.create({
        data: {
          name: 'New sprite'
        }
      })
      const uuid = sprite.id

      // Create folder with uuid
      const sprite_folder = Storage.getPublicPath('sprites', uuid)
      await fs.mkdir(sprite_folder, { recursive: true })

      callback(true)
    } catch (error) {
      console.error('Error creating sprite:', error)
      callback(false)
    }
  }
}
