import { BaseEvent } from '#application/base/baseEvent'
import { Zone } from '#entities/zone'
import ZoneRepository from '#repositories/zoneRepository'

interface IPayload {}

export default class ZoneListEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:zone_editor:zone:list', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: Zone[]) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      this.logger.info(`User ${(await this.getCharacter())!.getId()} has created a new zone via zone editor.`)

      const zones = await ZoneRepository.getAll()
      return callback(zones)
    } catch (error: any) {
      this.logger.error('gm:zone_editor:zone:list error', error.message)
      return callback([])
    }
  }
}
